@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,9 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_extensions.hxx"
 
-//#include <tools/presys.h>
 #include <vector>
-//#include <tools/postsys.h>
 #include <smart/com/sun/star/test/XSimpleTest.hxx>
 #include <smart/com/sun/star/lang/XMultiServiceFactory.hxx>  // for the multiservice-factories
 
@@ -53,7 +52,6 @@
 
 using namespace std;
 using namespace rtl;
-using namespace vos;
 using namespace usr;
 
 #define BUILD_ERROR(expr, Message)\
@@ -770,3 +768,5 @@ void OSaxWriterTest::testPerformance(const  XExtendedDocumentHandlerRef &r )
 
     printf( "Performance writing : %g s\n" , fEnd - fStart );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
